@@ -1,34 +1,29 @@
 """
-
 更新内容一览
-
 """
 
 """
 
-2022/3/7
-control_version:0.4.1
-blcoklyFile_version:0.1.1
-blockly_version:2.2.1
-
-"""
-
-"""
-
-2022/3/13
-control_version:0.4.2
-blcoklyFile_version:0.1.2
+2022/3/27
+control_version:0.5.2
+blcoklyFile_version:0.2.2
 blockly_version:2.2.1
 更新内容：
-1.修改了数字识别模型
-2.修改了数字对应的块
-3、shijue0库加入了两个函数，查找轮廓和返回图像类型。
-4、shijue0删除了一个变量self.Type，原本是用来返回图像类型的，现在被上面那个新函数代替。
-5、增加了轮廓检测的块
-6、修改了返回图像类型的块的代码区域的内容
+修改了blocklyFiles的块：硬件控制-->小车控制-->中的第二个块
+增加了屏幕函数
+修改了仿真器的块
 
+"""
 """
 
+2022/3/21
+control_version:0.5.1
+blcoklyFile_version:0.2.0
+blockly_version:2.2.1
+更新内容：
+修改了在树莓派不能调用摄像头的bug
+
+"""
 """
 2022/3/21
 control_version:0.5.0
@@ -44,14 +39,26 @@ blockly_version:2.2.1
 7.增加了背景图像切换的操作
 
 """
-
 """
 
-2022/3/21
-control_version:0.5.1
-blcoklyFile_version:0.2.0
+2022/3/13
+control_version:0.4.2
+blcoklyFile_version:0.1.2
 blockly_version:2.2.1
 更新内容：
-修改了在树莓派不能调用摄像头的bug
+1.修改了数字识别模型
+2.修改了数字对应的块
+3、shijue0库加入了两个函数，查找轮廓和返回图像类型。
+4、shijue0删除了一个变量self.Type，原本是用来返回图像类型的，现在被上面那个新函数代替。
+5、增加了轮廓检测的块
+6、修改了返回图像类型的块的代码区域的内容
+
+"""
+"""
+
+2022/3/7
+control_version:0.4.1
+blcoklyFile_version:0.1.1
+blockly_version:2.2.1
 
 """
