@@ -7,19 +7,20 @@
 from __future__ import division
 import time
 import sys
+import cv2
 
 '''
 这下面是屏幕需要的新库
 '''
 import os
 import logging  #加载字体
-from control.lcd import LCD_2inch4   #屏幕的包
-from PIL import Image,ImageDraw,ImageFont  #放图片的包
+from PIL import Image, ImageDraw, ImageFont, ImageFilter  #放图片的包
 
 system_platform = sys.platform
 if 'win' in system_platform:
     pass
 else:
+    from control.lcd import LCD_2inch4  # 屏幕的包
     import serial
     import Adafruit_DHT
     import RPi.GPIO as GPIO
@@ -624,11 +625,12 @@ class Mecanum_wheel():
     '''
 
     def car_turn_l(self, speed):
-        speed = speed / 12  # 这里就是转化，下面也同理
+        #和马哥探讨后决定还是角度每秒比较好，不转换了——3_26
+        #speed = speed / 12  # 这里就是转化，下面也同理
         self.car_contr(0, 0, speed)
 
     def car_turn_r(self, speed):
-        speed = speed / 12
+        #speed = speed / 12
         self.car_contr(0, 0, -speed)
 
     '''
@@ -667,7 +669,7 @@ class Mecanum_wheel():
     def car_circle_L(self, speed, radius):  # 左传（后面不做解释了）
         w = 110 * speed / radius
         w = w / 12  # 转换为角速度
-        print(speed, w)  # 这行是看参数的，注释掉方便以后调试
+        # print(speed, w)  # 这行是看参数的，注释掉方便以后调试
         self.car_contr(speed, 0, w)
 
     def car_circle_R(self, speed, radius):
@@ -804,3 +806,45 @@ class Screen():
         image = image.resize((320, 240), Image.ANTIALIAS)
 
         disp.ShowImage(image)
+
+    def video_show(self, video_path):
+        # 视频文件位置
+        cap = cv2.VideoCapture(video_path)
+        disp = LCD_2inch4.LCD_2inch4()
+        disp.Init()
+        disp.clear()
+        picture_show_time = cap.get(7)
+
+        while cap.isOpened:
+            ret, frame = cap.read()
+            image = Image.fromarray(cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
+            image = image.resize((320, 240), Image.ANTIALIAS)
+            #     image = image.filter(ImageFilter.SHARPEN)
+            disp.ShowImage(image)
+            picture_show_time -= 1
+            cv2.waitKey(1)
+            if not picture_show_time:
+                break
+
+        cap.release()
+
+    def live_view_camera(self):
+        disp = LCD_2inch4.LCD_2inch4()
+        disp.Init()
+        disp.clear()
+        cap = cv2.VideoCapture(0)
+        while True:
+            ret, frame = cap.read()
+            # cv2.imshow("capture", frame)
+            image = Image.fromarray(cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
+            image = image.resize((320, 240), Image.ANTIALIAS)
+            image = image.filter(ImageFilter.SHARPEN)
+            disp.ShowImage(image)
+
+            if cv2.waitKey(1) & 0xFF == ord('q'):
+                break
+
+        cap.release()
+
+
+
