@@ -74,10 +74,7 @@ class basicImg():
 
     # 获取摄像头
     def camera(self, num=0):
-        if 'win' in system_platform:
-            self.cam = cv2.VideoCapture(num,cv2.CAP_DSHOW)
-        else:
-            self.cam = cv2.VideoCapture(num)
+        self.cam = cv2.VideoCapture(num,cv2.CAP_DSHOW)
 
     def close_camera(self):
         self.cam.release()
